@@ -12,9 +12,10 @@
 import os, shutil, string, sys, time
 
 class Mooi:
+	MAX_CHOICES = 15
 	DIR = os.path.expandvars('${HOME}/Lavengro')
 	LRC = os.path.expandvars(DIR + os.sep + 'lavengrorc')
-	HDR = "\n\nLavengro - The Word Master" 
+	HDR = "\nLavengro - The Word Master" 
 	MODE = ['lavengro - programmed learning',
 			'test - one chance to answer, scored result',
 			'tutor - retest until all correct, no score',
@@ -58,22 +59,48 @@ class Mooi:
 		return lines
 
 	# get user to choose an element from thing
-	def query(self, thing, prompt):
-		print "\n--- 'q' to quit ---"
-		length = len(thing)
-		choice = length + 1
-		for i in range(0, length):
-			tokens = string.split(thing[i],':')
-			print '(' + `i+1` + ') ' + string.strip(tokens[0])
-		while ((choice > length) or (choice == self.prevUsrChoice)):
+	def show_choices(self, list, index):
+		length = len(list)
+		if (os.name != "nt"):
+			os.system("clear")
+		else:
+			os.system("cls")
+		i = index
+		choices = ['0']
+		print self.HDR
+		print "-------------------"
+		print '(0) quit'
+		while ((i < length) and
+			   (i < (index + self.MAX_CHOICES))):
+			print '('+`i+1`+') '+list[i]
+			choices.append(`i+1`)
+			i = i+1
+		if (i < length):
+			print '(m) more'
+		if (i > self.MAX_CHOICES):
+			print '(b) back'
+		print "-------------------"
+		return choices
+
+	def query(self, list, prompt):
+		last = 0
+		i = 1
+		choices = self.show_choices(list, last)
+		choice = None
+		while (choice not in choices):
 			choice = raw_input(prompt)
-			if (choice == 'q'):
-				self.exit(' ', 0)
-			else:
-				try:
-					choice = int(choice) - 1
-				except:
-					choice = length + 1
+			if (choice in ['m','b']):
+				if (choice == 'm'):
+					last = last + self.MAX_CHOICES
+				if (choice == 'b'):
+					last = last - self.MAX_CHOICES
+				if ((last < 0) or (last > len(list))):
+					last = 0
+				choices = self.show_choices(list, last)
+		if (choice == '0'):
+			self.exit(" ",0)
+		else:	
+			choice = int(choice)-1
 		return choice
 
 	#compare files by date, oldest first
@@ -285,9 +312,6 @@ class Mooi:
 	# - Lavengro - #
 	# load data for Lavengro instance
 	def loadData(self, data):
-		if not (self.header):
-			print self.HDR
-			self.header = 1
 		self.selectQuiz()
 		self.loadQuiz(data)
 		return 
